@@ -1,9 +1,29 @@
-//---------------------------------------------------------------------------
-//
-// amordialog.cpp
-//
-// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
-//
+/* amordialog.cpp
+**
+** Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #include <qcheckbox.h>
 #include <qlabel.h>
@@ -23,7 +43,7 @@
 // Constructor
 //
 AmorDialog::AmorDialog()
-    : KDialogBase(0, "amordlg", false, i18n("Options"), Ok|Cancel, Ok )
+    : KDialogBase(0, "amordlg", false, i18n("Options"), Ok|Apply|Cancel, Ok )
 {
     mConfig.read();
     QVBox *mainwidget = makeVBoxMainWidget();
@@ -64,7 +84,11 @@ AmorDialog::AmorDialog()
 
     checkBox = new QCheckBox(i18n("Show random tips"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotRandomTips(bool)));
-    checkBox->setChecked(mConfig.mTips);
+    checkBox->setChecked(mConfig.mTips); // always keep this one after the connect, or the QList would not be grayed when it should
+
+    checkBox = new QCheckBox(i18n("Use a random character"), mainwidget);
+    connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotRandomTheme(bool)));
+    checkBox->setChecked(mConfig.mRandomTheme);
 
     checkBox = new QCheckBox(i18n("Allow application tips"), mainwidget);
     connect(checkBox, SIGNAL(toggled(bool)), SLOT(slotApplicationTips(bool)));
@@ -87,7 +111,12 @@ AmorDialog::~AmorDialog()
 //
 void AmorDialog::readThemes()
 {
-    QStringList files(KGlobal::dirs()->findAllResources("appdata", "*rc"));
+    QStringList files;
+
+    // Non-recursive search for theme files, with the relative paths stored
+    // in files so that absolute paths are not used.
+    KGlobal::dirs()->findAllResources("appdata", "*rc", false, false, files);
+
     for (QStringList::ConstIterator it = files.begin();
 	 it != files.end();
 	 it++)
@@ -100,7 +129,7 @@ void AmorDialog::readThemes()
 //
 void AmorDialog::addTheme(const QString& file)
 {
-    KSimpleConfig config(file, true);
+    KSimpleConfig config(locate("appdata", file), true);
 
     config.setGroup("Config");
 
@@ -175,6 +204,16 @@ void AmorDialog::slotRandomTips(bool tips)
     mConfig.mTips = tips;
 }
 
+//---------------------------------------------------------------------------
+//
+// User toggled random character
+//
+void AmorDialog::slotRandomTheme(bool randomTheme)
+{
+    mThemeListBox->setEnabled(!randomTheme);
+    mConfig.mRandomTheme = randomTheme;
+}
+
 //---------------------------------------------------------------------------
 //
 // User toggled application tips
@@ -195,6 +234,16 @@ void AmorDialog::slotOk()
     accept();
 }
 
+//---------------------------------------------------------------------------
+//
+// User clicked Ok
+//
+void AmorDialog::slotApply()
+{
+    mConfig.write();
+    emit changed();
+}
+
 //---------------------------------------------------------------------------
 //
 // User clicked Cancel
