@@ -14,12 +14,13 @@
 QString int2time(int time)
 {
 	QString str;
-	if (time / 60) {
-		str.append(i18n("%1min").arg(time / 60));
-		str.append(" ");
-	}
+	if (time / 60)
+		str.append(i18n("%1 min").arg(time / 60));
 	if (time % 60)
-		str.append(i18n("%1s").arg(time % 60));
+          if (str.isEmpty())
+            str.append(i18n("%1 s").arg(time % 60));
+          else
+            str.append(i18n(" %1 s").arg(time % 60));
 	return str;
 }
 
@@ -46,7 +47,7 @@ void TeaListItem::setTime(int t)
 	tim = t;
 }
 
-void TeaListItem::setName(QString n)
+void TeaListItem::setName(const QString &n)
 {
 	nam = n;
 	QListViewItem::setText(0, n);
