@@ -99,9 +99,12 @@ void dockwidget::showWeather()
 
         tip += "<h3><center><nobr>" +
                m_weatherService->stationName( m_locationCode ) + " (" +
-               m_weatherService->stationCountry( m_locationCode ) + ")</nobr></center></h3><br>";
+               m_weatherService->stationCountry( m_locationCode ) + ")</nobr></center></h3>";
 
-        tip += QString("<table>"
+        if ( m_weatherService->currentIconString( m_locationCode ) == "dunno" )  // no data
+            tip += "<center><nobr>" + i18n("The network is currently offline...") + "</nobr></center>";
+
+        tip += QString("<br><table>"
                 "<tr><th><nobr>" + i18n( "Temperature:"   ) + "</nobr></th><td><nobr>%1</nobr></td>"
                     "<th><nobr>" + i18n( "Dew Point:"     ) + "</nobr></th><td><nobr>%2</nobr></td></nobr></tr>"
 
